@@ -101,6 +101,7 @@ _preset_clicked (HildonButton *button, TweakrProfileStatusPlugin *plugin)
     if (strcmp (path, "silent") == 0)
     {
         profile_set_profile ("silent");
+        basename = g_strdup (dgettext("osso-profiles", "profi_bd_silent"));
     }
     else
     {
@@ -112,12 +113,13 @@ _preset_clicked (HildonButton *button, TweakrProfileStatusPlugin *plugin)
         profile_set_profile ("general");
 
         basename = g_path_get_basename (path);
-        hildon_button_set_value (HILDON_BUTTON (plugin->priv->button), basename);
-        gconf_client_set_string (plugin->priv->gconf,
-                                 GCONF_PATH "/current-preset", basename, NULL);
-        g_free (basename);
     }
 
+    hildon_button_set_value (HILDON_BUTTON (plugin->priv->button), basename);
+    gconf_client_set_string (plugin->priv->gconf,
+                             GCONF_PATH "/current-preset", basename, NULL);
+    g_free (basename);
+
     gtk_dialog_response (GTK_DIALOG (plugin->priv->dialog), GTK_RESPONSE_OK);
     hildon_banner_show_information (NULL, NULL,
                                     _("Preset activated."));
